@@ -217,11 +217,10 @@ class NDCubeABC(astropy.nddata.NDDataBase):
 
         Examples
         --------
-        An example of cropping a region of interest on the Sun from a 3-D image-time cube:
+        >>> # An example of cropping a region of interest on the Sun from a 3-D image-time cube
         >>> point1 = [SkyCoord(-50*u.deg, -40*u.deg, frame=frames.HeliographicStonyhurst), None]  # doctest: +SKIP
         >>> point2 = [SkyCoord(0*u.deg, -6*u.deg, frame=frames.HeliographicStonyhurst), None]  # doctest: +SKIP
         >>> NDCube.crop(point1, point2) # doctest: +SKIP
-
         """
 
     @abc.abstractmethod
@@ -267,7 +266,7 @@ class NDCubeABC(astropy.nddata.NDDataBase):
 
         Examples
         --------
-        An example of cropping a region of interest on the Sun from a 3-D image-time cube:
+        >>> # An example of cropping a region of interest on the Sun from a 3-D image-time cube
         >>> NDCube.crop_by_values((-600, -600, 0), (0, 0, 0), units=(u.arcsec, u.arcsec, u.s)) # doctest: +SKIP
         """
 
@@ -1175,7 +1174,7 @@ class NDCube(NDCubeBase):
         new_wcs = ResampledLowLevelWCS(self.wcs.low_level_wcs, bin_shape[::-1])
 
         # Reform NDCube.
-        new_cube = type(self)(new_data, new_wcs, uncertainty=new_uncertainty, mask=new_mask,
+        new_cube = type(self)(data=new_data, wcs=new_wcs, uncertainty=new_uncertainty, mask=new_mask,
                               meta=self.meta, unit=new_unit)
         new_cube._global_coords = self._global_coords
         # Reconstitute extra coords
